.. _rdflib.store: Other modules


Store
-----
.. automodule:: rdflib.store
.. :noindex:

.. autoclass:: rdflib.store.Store
    :members:

Events
^^^^^^

.. autoclass:: rdflib.store.StoreCreatedEvent
    :members:

.. autoclass:: rdflib.store.TripleAddedEvent
    :members:

.. autoclass:: rdflib.store.TripleRemovedEvent
    :members:

